@@ -137,7 +137,7 @@ class HttpClient(object):
 
     def _post(self, rest_command, file=None, parameters=None, headers=None, data=None):
         return self._do_request('POST', rest_command, parameters=parameters,
-                                file=file, data=None)
+                                file=file, data=data)
 
 
 class AccessInfoMixin(object):
